@@ -339,7 +339,7 @@ static loff_t uio_llseek(struct file *filp, loff_t offset, int origin) {
 
     if(down_interruptible(&Buffer_lock)) { return -ERESTARTSYS; }
     BufRP += imin_uint(offset, avail_R());
-    if(BufRP > Buffer + Bufsize) { BufRP -= Bufsize; }
+    if(BufRP >= Buffer + Bufsize) { BufRP -= Bufsize; }
 
     up(&Buffer_lock);
     filp->f_dentry->d_inode->i_atime = CURRENT_TIME;
