@@ -1,7 +1,7 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/infod.c - INFO socket for RPLD
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004
+  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2005
   -- License restrictions apply (GPL v2)
 
   This file is part of ttyrpld.
@@ -163,10 +163,12 @@ static void getinfo_text(uint32_t dev, int fd) {
         struct HXbtrav *travp;
 
         skprintf(fd,
-          "==========================================================================\n"
+          "=========================================================="
+          "================\n"
           "  *       %9llu %9llu ttyrpld " TTYRPLD_VERSION "\n"
           "  IOCD: %zu/%zu/%zu/%zu  RW: %zu/%zu  I: %zu  B: %zu\n"
-          "--------------------------------------------------------------------------\n",
+          "----------------------------------------------------------"
+          "----------------\n",
           Stats.in, Stats.out, Stats.init, Stats.open, Stats.close,
           Stats.deinit, Stats.read, Stats.write, Stats.ioctl, Stats.badpack
         );
@@ -177,7 +179,8 @@ static void getinfo_text(uint32_t dev, int fd) {
             print_entry_text(fd, nd->data);
         }
 
-        skprintf(fd, "--------------------------------------------------------------------------\n");
+        skprintf(fd, "-----------------------------------------------"
+         "---------------------------\n");
         HXbtrav_free(travp);
     } else {
         struct tty *tty;
