@@ -69,7 +69,6 @@ static void sighandler_int(int);
 static void sighandler_alrm(int);
 static void sighandler_pipe(int);
 
-static void chkconf(void);
 static int get_options(int *, const char ***);
 static int read_config(const char *);
 static int read_config_bp(const char *, const char *);
@@ -575,46 +574,10 @@ static void sighandler_pipe(int s) {
 }
 
 //-----------------------------------------------------------------------------
-static void chkconf(void) {
-    /* Check whether the configuration file has been modified compared to the
-    original that was once installed. Exits with EXIT_FAILURE if modified.
-    `make install` will then NOT update it with the (possibly new)
-    configuration from the ttyrpld source tree. */
-    struct stat sb;
-    char buf[16];
-    FILE *fp;
-
-    if(stat("/etc/rpld.conf", &sb) != 0) {
-        if(errno == ENOENT) {
-            exit(EXIT_SUCCESS);
-        }
-        exit(EXIT_FAILURE);
-    }
-    if(sb.st_size == 0) {
-        exit(EXIT_SUCCESS);
-    }
-    if((fp = popen("md5sum /etc/rpld.conf", "r")) == NULL) {
-        exit(EXIT_FAILURE);
-    }
-    memset(buf, sizeof(buf), '\0');
-    if(fscanf(fp, "%16s", buf) != 1) {
-        exit(EXIT_FAILURE);
-    }
-    fclose(fp);
-    if(strncmp(buf, "d0b2b74655540c7c11fd872eaddaa862", 16) != 0) {
-        exit(EXIT_FAILURE);
-    }
-    exit(EXIT_SUCCESS);
-    return;
-}
-
 static int get_options(int *argc, const char ***argv) {
     static const char *_empty_argv[] = {NULL};
     char *tmp;
     struct poptOption options_table[] = {
-        {"chkconf", 0, POPT_ARG_NONE | POPT_ARGFLAG_DOC_HIDDEN, NULL,
-         0x100 | 'C', "Check whether the configuration file has been modified"
-         " (used by `make install` when updating)", NULL},
         {NULL, 'D', POPT_ARG_STRING, &Opt.ovdev, 0,
          "Path to the RPL device", "file"},
         {NULL, 'I', POPT_ARG_VAL, &Opt.infod_start, 1,
@@ -644,9 +607,6 @@ static int get_options(int *argc, const char ***argv) {
     ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
     while((c = poptGetNextOpt(ctx)) >= 0) {
         switch(c) {
-            case 0x100 | 'C':
-                chkconf();
-                break;
             case 'Q':
                 Opt.dolog = 0;
                 break;
